/*
 *    ImageServlet
 *  Copyright (C) 2010 Mark Elam
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *  For more information about the GNU Public license see:
 *  http://www.gnu.org/copyleft/gpl.html
 *
 *  ImageServlet is at:
 *  http://www.subtrack.org.uk
 *
 */
package uk.org.subtrack.imaging
import java.io.InputStream
import scala.xml.XML

object ImagesDocument {

  class Size(val width:int,val height:int)
  class Property(val name:String,val value:String)
  class Image(val classname:String,
              val name:String,
              val size:Size,
              val baseimage:String,
              val properties:List[Property])

  def Images(is:InputStream):List[Image]={
    val xmlDocument =XML.load(is)
    implicit def stringToInt(x:String) = x match {
      case ""=> 0
      case _ => x.toInt
    }
    xmlDocument match {
      case <images>{images @ _*}</images> =>
        (for{
            image @ <image>{_*}</image> <- images
            val classname=(image \ "@className").text
            val name=(image \ "@name").text
            val sizeNode=(image \ "size")
            val width=(sizeNode\ "@width").text
            val height=(sizeNode \ "@height").text
            val size=new Size(width,height)
            val baseimage=((image \ "baseimage") \ "@name").text
            val properties=(
              for {
                prop <- image \ "property"
                val name=(prop \ "@name" ).text
                val value=(prop \ "@value" ).text
                newProp=new Property(name,value)
              } yield newProp).toList
            val imageXML=new Image(classname,name,size,baseimage,properties)
          } yield imageXML).toList
    }
  }

}
